# Related Resources

Here are some resources related to the Gateway Provisioners project.

- [Jupyter.org](https://jupyter.org) - the official Jupyter organization website.
- [Jupyter Server Team Compass](https://github.com/jupyter-server/team-compass#jupyter-server-team-compass) - all things related to the Jupyter Server organization.
- [Jupyter Calendar - Community Meetings](https://docs.jupyter.org/en/latest/community/content-community.html#jupyter-community-meetings) - the set of Jupyter-related meetings - all are welcome!
- [Jupyter Community Discourse Forum](https://discourse.jupyter.org/) - the public forum for Jupyter-related questions, discussions, and announcements.
- [Jupyter Enterprise Gateway Github Repo](https://github.com/jupyter-server/enterprise_gateway) - the source code for Enterprise Gateway - which supports remote kernels using Process Proxies. It's 4.0 release will support kernel provisioners and process proxy support will go away.
- [Jupyter Kernel Gateway Github Repo](https://github.com/jupyter-server/kernel_gateway) - the source code for Kernel Gateway - which immediately supports kernel provisioners by virtue of using the base `KernelManager` class.
- [Jupyter Server Github Repo](https://github.com/jupyter-server/jupyter_server) - the source code for the Jupyter Server.
- [Jupyter Client Github Repo](https://github.com/jupyter/jupyter_client) - the source code for the base kernel management, provisioner, and messaging (client) classes.
